@@ -1,6 +1,7 @@
 """Simple wrapper of GitHub REST APIs.
 """
 from typing import Callable
+from pathlib import Path
 import json
 import requests
 
@@ -17,6 +18,15 @@ def build_http_headers(token: str) -> dict[str, str]:
     return headers
 
 
+def _is_rust(file: str) -> bool:
+    path = Path(file)
+    if path.name in ("Cargo.toml", "Cargo.lock"):
+        return True
+    if path.suffix == ".rs":
+        return True
+    return False
+
+
 class Repository:
     """Abstraction of a GitHub repository."""
 
@@ -30,6 +40,8 @@ class Repository:
         self.owner = owner
         self.repo = repo
         self._url_pull = f"https://api.github.com/repos/{owner}/{repo}/pulls"
+        self._url_branches = f"https://api.github.com/repos/{owner}/{repo}/branches"
+        self._url_refs = f"https://api.github.com/repos/{owner}/{repo}/git/refs"
         self._headers = build_http_headers(token)
 
     def list_pull_requests(self) -> list[dict]:
@@ -106,24 +118,51 @@ class Repository:
             timeout=10,
         )
         if not resp.ok:
-            raise resp.raise_for_status
+            resp.raise_for_status()
         return resp.json()
 
+    def list_branches(self) -> dict[str, str]:
+        """List branches in this repository."""
+        resp = requests.get(url=self._url_branches, headers=self._headers, timeout=10)
+        if not resp.ok:
+            resp.raise_for_status()
+        return resp.json()
 
-def has_change(token: str, pr_number: int, pred: Callable[[str], bool] | None = None):
-    """Check whether a PR has any change satisfying pred.
+    def delete_ref(self, ref: str) -> None:
+        """Delete a reference from this repository.
+        :param ref: The reference to delete from this repository.
+        """
+        resp = requests.delete(
+            f"{self._url_refs}/{ref}", headers=self._headers, timeout=10
+        )
+        if not resp.ok:
+            resp.raise_for_status()
 
-    :param token: The authorization token for GitHub REST API.
-    :param pr_number: The number of the corresponding pull request.
-    :param pred: A boolean predictor (always true by default)
-    checking whether a single file has specific changes.
-    """
+    def delete_branch(self, branch: str) -> None:
+        """Delete a branch from this repository.
+        :param branch: The branch to delete from this repository.
+        """
+        self.delete_ref(ref=f"heads/{branch}")
 
-    def _always_true(_):
-        return True
+    def pr_has_change(
+        self, pr_number: int, pred: Callable[[str], bool] = lambda _: True
+    ):
+        """Check whether a PR has any change satisfying pred.
 
-    if pred is None:
-        pred = _always_true
-    repo = Repository(token=token, owner="fun-poker-game", repo="poker-rs")
-    files = repo.list_pull_request_files(pr_number)
-    return any(pred(file["filename"]) for file in files)
+        :param pr_number: The number of the corresponding pull request.
+        :param pred: A boolean predictor (always true by default)
+        checking whether a single file has specific changes.
+        """
+        files = self.list_pull_request_files(pr_number)
+        return any(pred(file["filename"]) for file in files)
+
+    def pr_has_rust_change(
+        self, pr_number: int, pred: Callable[[str], bool] = _is_rust
+    ):
+        """Check whether a PR has any Rust-related changes.
+
+        :param token: The authorization token for GitHub REST API.
+        :param pr_number: The number of the corresponding pull request.
+        :param pred: A customized boolean predictor checking Rust-related changes.
+        """
+        return self.pr_has_change(pr_number=pr_number, pred=pred)
